		private void CreateTableThree()
        {
            ReportDocument = new RichTextDocument();
            TextEditorWidth = "900";

            ReportDocument.RootNode.Body.ChildNodes.Add(CreateParagraph(_csBoldText, ParagraphAlignment.Start,
                "TABLE 3"));

            string error;

            var table3Node = ReportDocument.InsertTable(ReportDocument.AggregateOffsetCount, 8, 2, out error,
                TableExtentBehavior.FitTableToWindow);
            table3Node.Settings = new TableSettings();

            /* Create Rows for Table */
            var firstRow = CreateRow(table3Node, 0);
            var secondRow = CreateRow(table3Node, 1);

            /* Create Cells for Rows */
            var cell_1R1C = BuildCell(firstRow, 1, false, 0);
            var cell_1R2C = BuildCell(firstRow, 1, false, 1);
            var cell_1R3C = BuildCell(firstRow, 1, false, 2);
            var cell_1R4C = BuildCell(firstRow, 1, false, 3);
            var cell_1R5C = BuildCell(firstRow, 1, false, 4);
            var cell_1R6C = BuildCell(firstRow, 1, false, 5);
            var cell_1R7C = BuildCell(firstRow, 1, false, 6);
            var cell_1R8C = BuildCell(firstRow, 1, false, 7);

            var cell_2R1C = BuildCell(secondRow, 1, false, 0);
            var cell_2R2C = BuildCell(secondRow, 1, false, 1);
            var cell_2R3C = BuildCell(secondRow, 1, false, 2);
            var cell_2R4C = BuildCell(secondRow, 1, false, 3);
            var cell_2R5C = BuildCell(secondRow, 1, false, 4);
            var cell_2R6C = BuildCell(secondRow, 1, false, 5);
            var cell_2R7C = BuildCell(secondRow, 1, false, 6);
            var cell_2R8C = BuildCell(secondRow, 1, false, 7);

            /* Create Headers for Columns */
            CreateHeaderCell(cell_1R1C, _csSmallText, "Sample 1");
            CreateHeaderCell(cell_1R2C, _csSmallText, "Sample 2");
            CreateHeaderCell(cell_1R3C, _csSmallText, "Sample 3");
            CreateHeaderCell(cell_1R4C, _csSmallText, "Sample 4");
            CreateHeaderCell(cell_1R5C, _csSmallText, "Sample 5");
            CreateHeaderCell(cell_1R6C, _csSmallText, "Sample 6");
            CreateHeaderCell(cell_1R7C, _csSmallText, "Sample 7");
            CreateHeaderCell(cell_1R8C, _csSmallText, "Sample 8");
        }
		
        private TableRowNode CreateRow(TableNode table, int rowIndex)
        {
            TableRowNode row = table.Rows[rowIndex];
            row.Settings = new TableRowSettings {Height = new TableRowHeight(new Extent(350), ExtentRule.AtLeast)};

            return row;
        }
		
        private TableCellNode BuildCell(TableRowNode row, int columnSpan, bool verticalMerge, int visibleColumnsIndex)
        {
            var cellSettings = new TableCellSettings();
            cellSettings.ColumnSpan = columnSpan;

            cellSettings.VerticalMerge = verticalMerge ? TableCellVerticalMerge.Continue : TableCellVerticalMerge.Restart;

            var cell = row.ChildNodes[visibleColumnsIndex] as TableCellNode;
            cell.Settings = cellSettings;

            return cell;
        }
		
        private ParagraphNode AddDataToCell(TableCellNode cell, string data)
        {
            var paragraph = cell.ChildNodes[0] as ParagraphNode;
            paragraph.ChildNodes.Add(CreateRunNodeWithContent(_csRegularText, data));
            paragraph.Settings = new ParagraphSettings { ParagraphAlignment = ParagraphAlignment.End };

            return paragraph;
        }
		
        private ParagraphNode CreateHeaderCell(TableCellNode cell, CharacterSettings characterSettings, string header)
        {
            var paragraph = cell.ChildNodes[0] as ParagraphNode;
            paragraph.ChildNodes.Add(CreateRunNodeWithContent(characterSettings, header));
            paragraph.Settings = new ParagraphSettings { ParagraphAlignment = ParagraphAlignment.Center };

            return paragraph;
        }
		
        private RunNode CreateRunNodeWithContent(CharacterSettings cs, string content)
        {
            var rn = new RunNode();
            if (cs != null) rn.Settings = cs;
            if (content != null) rn.SetText(content);
            return rn;
        }
		
        private ParagraphNode CreateParagraph(CharacterSettings csSettings, ParagraphAlignment alignment,
            string nodeText)
        {
            var paraSettings = new ParagraphSettings {ParagraphAlignment = alignment};
            paraSettings.Spacing = new ParagraphSpacingSettings {LineSpacing = new LineSpacing(1)};

            var paragraph = new ParagraphNode();
            paragraph.ChildNodes.Add(CreateRunNodeWithContent(csSettings, nodeText));
            paragraph.Settings = paraSettings;

            return paragraph;
        }